@@ -8,22 +8,22 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         SocialNetworks.objects.create(
             title="Facebook",
-            icon_ui='fa fa-facebook',
+            icon_ui='fab fa-facebook',
             link="https://facebook.com")
         SocialNetworks.objects.create(
             title="Instagram",
-            icon_ui='fa fa-instagram',
+            icon_ui='fab fa-instagram',
             link="https://instagram.com")
         SocialNetworks.objects.create(
             title="Twitter",
-            icon_ui='fa fa-twitter',
+            icon_ui='fab fa-twitter',
             link="https://twitter.com")
         SocialNetworks.objects.create(
             title="VK",
-            icon_ui='fa fa-vk',
+            icon_ui='fab fa-vk',
             link="https://vk.com")
         SocialNetworks.objects.create(
             title="Github",
-            icon_ui='fa fa-github',
+            icon_ui='fab fa-github',
             link="https://github.com")
-        self.stdout.write('Success soc. networks')
+        self.stdout.write('Success add soc. networks')
